param T;  # Anzahl der Perioden

set HAERTE;   # Menge der Härtegrade
set KAT;     # Menge der Mahlkategorien
set TIME:= {1..T};   # Menge der Perioden

param maxNuesse >=0;   # maximale Kapazit�t der N�sse
param anflager{KAT} default 0;  # Anfangslagerbestand
param ertrag{HAERTE,KAT} >=0;   # Ertrag an gemahlenen Nüssen mit unterschiedlichen H�rtegraden
param kosten{HAERTE} >=0;  # Kosten für das Mahlen der Nüsse für jeden Härtegrad
param lagkost >=0;  # Lagerkosten
param nachfr{KAT,TIME} >=0; # Nachfrage der Kategorien in jeder Periode

var xgemNuesse{j in KAT, t in TIME} >=0 integer;  # Menge der gemahlenen Nüsse jeder Periode
var xhaegrad{i in HAERTE, t in TIME} >=0; # Menge der Nüsse, die jede Periode mit den verschiedenen Härtegraden gemahlt werden
var xlag{j in KAT,t in {0} union TIME} >=0; # Lagerbestand
var xaktiv{i in HAERTE,t in TIME} binary; # b) 1, Mühle ist in der Periode t aktiv, sonst 0

# Zielfunktion: Kosten für Härtegrad + Lagerkostem
minimize Kosten: sum{i in HAERTE,t in TIME}kosten[i]*xhaegrad[i,t] + 
                 sum{j in KAT,t in TIME}lagkost*xlag[j,t];

# Kapazität der Nüsse
s.t. KapNuesse {t in TIME}: sum{j in HAERTE} xhaegrad[j,t] <= maxNuesse;

# Mahlen der Nüsse mit den verschiedenen Härtegraden
s.t. Ertrag {j in KAT,t in TIME}: sum{i in HAERTE} ertrag[i,j]*xhaegrad[i,t] = xgemNuesse[j,t];

# Lagerbestand
s.t. Lager {j in KAT,t in TIME}: xlag[j,t] = xlag[j,t-1] - nachfr[j,t] + xgemNuesse[j,t];

# Anfangslager
s.t. Anfangslager {j in KAT}: xlag[j,0] = anflager[j];

# b) zwei Mühlen dürfen maximal aktiv sein
s.t. Muehle {t in TIME}: sum{i in HAERTE} xaktiv[i,t] <= 2;

# b) nur wenn Mühle aktiv ist, wird mit dieser gemahlt
s.t. MengeUB {i in HAERTE,t in TIME}: xhaegrad[i,t] <= maxNuesse*xaktiv[i,t];
